@@ -10,7 +10,8 @@
 
 #include <KPluginFactory>
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 /**
    @class Plugin
 
@@ -21,9 +22,7 @@ namespace CalendarSupport {
 */
 class Plugin
 {
-    enum {
-        INTERFACE_VERSION = 2
-    };
+    enum { INTERFACE_VERSION = 2 };
 
 public:
     static int interfaceVersion()
